==> aws-cdk-lib-2.0.0-rc.6-sources.jar: software/amazon/awscdk/services/globalaccelerator/IEndpoint.java <==
package software.amazon.awscdk.services.globalaccelerator;

/**
 * (experimental) An endpoint for the endpoint group.
 * <p>
 * Implementations of <code>IEndpoint</code> can be found in the <code>aws-globalaccelerator-endpoints</code> package.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.29.0 (build 41df200)", date = "2021-06-02T09:55:31.299Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_globalaccelerator.IEndpoint")
@software.amazon.jsii.Jsii.Proxy(IEndpoint.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface IEndpoint extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) The region where the endpoint is located.
     * <p>
     * If the region cannot be determined, <code>undefined</code> is returned
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getRegion() {
        return null;
    }

    /**
     * (experimental) Render the endpoint to an endpoint configuration.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.Object renderEndpointConfiguration();

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.globalaccelerator.IEndpoint.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * (experimental) The region where the endpoint is located.
         * <p>
         * If the region cannot be determined, <code>undefined</code> is returned
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public final @org.jetbrains.annotations.Nullable java.lang.String getRegion() {
            return software.amazon.jsii.Kernel.get(this, "region", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * (experimental) Render the endpoint to an endpoint configuration.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public final @org.jetbrains.annotations.NotNull java.lang.Object renderEndpointConfiguration() {
            return software.amazon.jsii.Kernel.call(this, "renderEndpointConfiguration", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }
    }

    /**
     * Internal default implementation for {@link IEndpoint}.
     */
    @software.amazon.jsii.Internal
    interface Jsii$Default extends IEndpoint {

        /**
         * (experimental) The region where the endpoint is located.
         * <p>
         * If the region cannot be determined, <code>undefined</code> is returned
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        default @org.jetbrains.annotations.Nullable java.lang.String getRegion() {
            return software.amazon.jsii.Kernel.get(this, "region", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * (experimental) Render the endpoint to an endpoint configuration.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        default @org.jetbrains.annotations.NotNull java.lang.Object renderEndpointConfiguration() {
            return software.amazon.jsii.Kernel.call(this, "renderEndpointConfiguration", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/globalaccelerator/IEndpoint.java <==
package software.amazon.awscdk.services.globalaccelerator;

/**
 * An endpoint for the endpoint group.
 * <p>
 * Implementations of <code>IEndpoint</code> can be found in the <code>aws-globalaccelerator-endpoints</code> package.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:10.317Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_globalaccelerator.IEndpoint")
@software.amazon.jsii.Jsii.Proxy(IEndpoint.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface IEndpoint extends software.amazon.jsii.JsiiSerializable {

    /**
     * The region where the endpoint is located.
     * <p>
     * If the region cannot be determined, <code>undefined</code> is returned
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getRegion() {
        return null;
    }

    /**
     * Render the endpoint to an endpoint configuration.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object renderEndpointConfiguration();

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.globalaccelerator.IEndpoint.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * The region where the endpoint is located.
         * <p>
         * If the region cannot be determined, <code>undefined</code> is returned
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.Nullable java.lang.String getRegion() {
            return software.amazon.jsii.Kernel.get(this, "region", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Render the endpoint to an endpoint configuration.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public final @org.jetbrains.annotations.NotNull java.lang.Object renderEndpointConfiguration() {
            return software.amazon.jsii.Kernel.call(this, "renderEndpointConfiguration", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }
    }

    /**
     * Internal default implementation for {@link IEndpoint}.
     */
    @software.amazon.jsii.Internal
    interface Jsii$Default extends IEndpoint {

        /**
         * The region where the endpoint is located.
         * <p>
         * If the region cannot be determined, <code>undefined</code> is returned
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        default @org.jetbrains.annotations.Nullable java.lang.String getRegion() {
            return software.amazon.jsii.Kernel.get(this, "region", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Render the endpoint to an endpoint configuration.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        default @org.jetbrains.annotations.NotNull java.lang.Object renderEndpointConfiguration() {
            return software.amazon.jsii.Kernel.call(this, "renderEndpointConfiguration", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }
    }
}
